@@ -1,5 +1,5 @@
 # Copyright 2004-2016, Ned Batchelder.
-# Copyright (c) 2018 Bobby Noelte.
+# Copyright (c) 2018..2020 Bobby Noelte.
 #
 # SPDX-License-Identifier: MIT
 
@@ -8,20 +8,19 @@ import sys
 class RedirectableMixin(object):
     __slots__ = []
 
+    ##
+    # @brief Redirect status and error reporting.
+    #
+    # Assign new files for standard out and/or standard error.
+    #
+    # @param stdout
+    # @param stderr
     def set_standard_streams(self, stdout=None, stderr=None):
-        """ Assign new files for standard out and/or standard error.
-        """
         if stdout:
             self._stdout = stdout
         if stderr:
             self._stderr = stderr
 
-    def prout(self, s, end="\n"):
-        print(s, file=self._stdout, end=end)
-
-    def prerr(self, s, end="\n"):
-        print(s, file=self._stderr, end=end)
-
 
 class Redirectable(RedirectableMixin):
     """ An object with its own stdout and stderr files.
